@@ -5,6 +5,7 @@ import typing as tp
 
 from django.db import models
 
+from ._create_django_model import InspectDataclass
 from ._decorator import BACKEND_LINKER
 from ._decorator import django_model
 from ._protocols import T
@@ -17,7 +18,10 @@ class DjangoStore:
     def dump(self, dc_obj: tp.Any) -> tuple[models.Model, bool]:
         model = django_model(dc_obj)
         kwgs, m2m = self.dataclass_to_django(dc_obj)
-        dj_obj, created = model.objects.using(self.identifier).update_or_create(**kwgs)
+        identifying, defaults = self._split_of_pk(dc_obj, kwgs)
+        dj_obj, created = model.objects.using(self.identifier).update_or_create(
+            **identifying, defaults=defaults
+        )
 
         for key, vals in m2m.items():
             # remove old ones
@@ -42,6 +46,8 @@ class DjangoStore:
             raise RuntimeError(
                 f"found {len(hits)} entries matching filter_kwgs {filter_kwgs}, be more specific!"
             )
+        if len(hits) == 0:
+            raise RuntimeError(f"found no entries matching filter_kwgs {filter_kwgs}!")
         return hits[0]  # type: ignore
 
     def dataclass_to_django(self, dc_obj: tp.Any) -> tp.Any:
@@ -82,3 +88,13 @@ class DjangoStore:
 
             obj_kwgs[field.name] = val
         return dataclass(**obj_kwgs)
+
+    @classmethod
+    def _split_of_pk(
+        cls, dc_obj: tp.Any, kwgs: dict[str, tp.Any]
+    ) -> tuple[dict[str, tp.Any], dict[str, tp.Any]]:
+        ident_keys = InspectDataclass(dc_obj).get_identifying_parameter()
+        return (
+            {key: kwgs[key] for key in kwgs.keys() & ident_keys},
+            {key: kwgs[key] for key in kwgs.keys() ^ ident_keys},
+        )
